#
# spec file for package python-nocasedict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-nocasedict
Version:        2.0.4
Release:        1.4
Summary:        A case-insensitive ordered dictionary for Python
License:        LGPL-2.1-or-later
URL:            https://github.com/pywbem/nocasedict
Source:         https://files.pythonhosted.org/packages/source/n/nocasedict/nocasedict-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Class `NocaseDict`_ is a case-insensitive ordered dictionary that preserves
the original lexical case of its keys.

%prep
%setup -q -n nocasedict-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/nocasedict
%{python_sitelib}/nocasedict-%{version}.dist-info

%changelog
* Mon Sep 30 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.4:
  * Fixed safety issues up to 2024-08-18.
  * Test: Increased versions of GitHub Actions plugins used, to
    eliminate warnings about node v16.
* Wed May  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.3:
  * Installation of this package using “setup.py” is no longer supported.
  * Fixed issues resulting from removal of support for pytest.warns(None)
    in pytest version 8.
  * Added support for Python 3.12.
- Switch to pyproject macros.
* Thu Sep 14 2023 pgajdos@suse.com
- version update to 2.0.1
  * Fixed coveralls issues with KeyError and HTTP 422 Unprocessable Entity.
  * Removed support for Python 2.7, 3.4, 3.5. The minimum required Python version
    is now 3.6. This was needed in order to add Python type hints (issue #123).
  * Enabled Github Actions for stable branches.
  * Addressed new issues of Pylint 2.16.
  * Added type hints and type checking with MyPy (issue #123).
  * Resurrected support for byte string keys that was removed in version 1.1.0.
    (issue #139)
  * The default casefolding method on Python 3 was changed from `str.lower()`
    to `str.casefold()`. This changes the matching of the case-insensitive keys.
    This shold normally be an improvement, but in case you find that you are
    negatively affected by this change, you can go back to the `str.lower()`
    method by overriding the `NocaseDict.__casefold__()` method with a method
    that calls `str.lower()`. (issue #122)
  * Added support for Python 3.11.
  * Changed the default casefolding method on Python 3 to be `str.casefold()`
    in order to improve Unicode support. On Python 2, it remains `str.lower()`.
    Added support for user-defined casefolding. (issue #122)
- drop python-six dependency
* Sat Oct  1 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.4:
  * Fixed recursion issue with flake8 5.0
  * Add python 3.7 support
* Wed Jun  8 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.3:
  * Mitigated the coveralls HTTP status 422 by pinning coveralls-python to <3.0.0 (issue #55).
  * Fixed issues raised by new Pylint 2.9 and 2.10.
  * Fixed a dependency error that caused importlib-metadata to be installed on
    Python 3.8, while it is included in the Python base.
  * Disabled new Pylint issue 'consider-using-f-string', since f-strings were
    introduced only in Python 3.6.
  * Fixed install error of wrapt 1.13.0 on Python 2.7 on Windows due to lack of
    MS Visual C++ 9.0 on GitHub Actions, by pinning it to <1.13.
  * Fixed potential issue with Sphinx/docutils versions on Python 2.7.
  * Fixed error when installing virtualenv in install test on Python 2.7.
  * Fixed that the added setup.py commands (test, leaktest, installtest) were
    not displayed. They are now displayed at verbosity level 1 (using '-v').
  * Support for Python 3.10: Added Python 3.10 in GitHub Actions tests, and in package metadata.
  * Removed old tools that were needed for travis and Appveyor but no longer on
* Mon Feb  1 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Migrated from Travis and Appveyor to GitHub Actions. This required changes
    in several areas including dependent packages used for testing and
    coverage. This did not cause any changes on dependent packages used for the
    installation of the package.
* Tue Oct 13 2020 Benjamin Greiner <code@bnavigator.de>
- initial specfile for version 1.0.1
